import { assertNever } from "@fern-api/core-utils";
import { OperatorType } from "./OperatorType";
import { AstNode } from "./core/AstNode";
export class Operator extends AstNode {
    operator;
    lhs;
    rhs;
    constructor({ operator, lhs, rhs }) {
        super();
        this.operator = operator;
        this.lhs = lhs;
        this.inheritReferences(lhs);
        this.rhs = rhs;
        this.inheritReferences(rhs);
    }
    getOperatorString() {
        switch (this.operator) {
            case OperatorType.Or:
                return "or";
            case OperatorType.And:
                return "and";
            case OperatorType.Add:
                return "+";
            case OperatorType.Subtract:
                return "-";
            case OperatorType.Multiply:
                return "*";
            case OperatorType.Divide:
                return "/";
            case OperatorType.Modulo:
                return "%";
            case OperatorType.LeftShift:
                return "<<";
            case OperatorType.RightShift:
                return ">>";
            default:
                assertNever(this.operator);
        }
    }
    write(writer) {
        this.lhs.write(writer);
        writer.write(" ");
        writer.write(this.getOperatorString());
        writer.write(" ");
        this.rhs.write(writer);
    }
}
