import { Type } from "./Type";
import { AstNode } from "./core/AstNode";
import { Writer } from "./core/Writer";
interface IterableConfig {
    endWithComma?: boolean;
}
interface StrConfig {
    multiline?: boolean;
    startOnNewLine?: boolean;
    endWithNewLine?: boolean;
}
interface DictEntry {
    key: AstNode;
    value: AstNode;
}
export declare class TypeInstantiation extends AstNode {
    private readonly internalType;
    private constructor();
    static int(value: number): TypeInstantiation;
    static float(value: number): TypeInstantiation;
    static bool(value: boolean): TypeInstantiation;
    static str(value: string, config?: StrConfig): TypeInstantiation;
    static bytes(value: string): TypeInstantiation;
    static list(values: AstNode[], config?: IterableConfig): TypeInstantiation;
    static set(values: AstNode[], config?: IterableConfig): TypeInstantiation;
    static tuple(values: AstNode[], config?: IterableConfig): TypeInstantiation;
    static dict(entries: DictEntry[], config?: IterableConfig): TypeInstantiation;
    static none(): TypeInstantiation;
    static uuid(value: string): TypeInstantiation;
    write(writer: Writer): void;
    private writeStringWithTripleQuotes;
    /**
     * Escapes certain special characters if they're NOT already preceded
     * by a backslash. Specifically:
     *
     *   - "  -> \"
     *   - '  -> \'
     *   - \  -> \\
     *   - literal \t -> \t
     *   - literal \n -> \n
     *   - literal \r -> \r
     *
     * Uses a negative lookbehind `(?<!\\)` to handle consecutive matches like
     * \n\n correctly, since each \n is independently matched in the original string.
     *
     * @param input The input string to be escaped
     */
    private escapeString;
}
export { Type };
